Crate system_data
source ·Re-exports
Modules
Functions
- A package for collect information about OS, CPU and Disk Drive of a windows operating system. You can collect disk information from any device with just a function call. you will be able to collect the
OS Information,CPU InformationandDisk Informationinformation of a windows system with this package.